| geophagus_delims | R Documentation |
This is a data frame containing species delimitation partitions for all the 137 unique haplotypes of geophagus generated using functions contained in this package. Use report_delim to check number of lineages per method.
geophagus_delims
A dataframe with 137 rows and 9 columns:
Unique haplotype labels
species partitions for ABGD method
species partitions for ASAP method
species partitions for bGMYC method
species partitions for GMYC method
species partitions for locmin method
species partitions following NCBI taxonomy
species partitions for mPTP method
species partitions for PTP method
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.