| report_delim | R Documentation |
report_delim() reports the number of unique species partitions in delim.
report_delim(delim, verbose = TRUE)
delim |
Output from any |
verbose |
Logical. If TRUE, returns a message and a tabulated summary of |
For each column in delim, report_delim() will calculate the
number of unique partitions and print them to Console. If delim is an output from *_tbl(),
report_delim() will get unique species partitions using vec_unique_count.
If delim is an output from delim_join or delim_consensus, values are summarized by using
n_distinct with na.rm = TRUE. This is to prevent any columns with
NA values to be interpreted as species partitions.
an object of class tbl_df].
Rupert A. Collins, Pedro S. Bittencourt
# report geophagus delimitations
report_delim(geophagus_delims)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.